# -*- coding: utf-8 -*-
# ///////////////////////////////////////////////////////////////

# IMPORT BASE
# ///////////////////////////////////////////////////////////////

# IMPORT SPECS
# ///////////////////////////////////////////////////////////////

# IMPORT / GUI AND MODULES AND WIDGETS
# /////////////////////////////////////////////////////////////////////////////////////////////
from .base_resources import *

## ==> GLOBALS
# ///////////////////////////////////////////////////////////////

## ==> VARIABLES
# ///////////////////////////////////////////////////////////////

## ==> CLASSES
# ///////////////////////////////////////////////////////////////


class Images:
    pass
    logo_placeholder = ":/images/images/logo-placeholder.jpg"


class Icons:
    pass
    cil_3d = ":/icons/icons/cil-3d.png"
    cil_4k = ":/icons/icons/cil-4k.png"
    cil_account_logout = ":/icons/icons/cil-account-logout.png"
    cil_action_redo = ":/icons/icons/cil-action-redo.png"
    cil_action_undo = ":/icons/icons/cil-action-undo.png"
    cil_airplane_mode_off = ":/icons/icons/cil-airplane-mode-off.png"
    cil_airplane_mode = ":/icons/icons/cil-airplane-mode.png"
    cil_alarm = ":/icons/icons/cil-alarm.png"
    cil_align_center = ":/icons/icons/cil-align-center.png"
    cil_align_left = ":/icons/icons/cil-align-left.png"
    cil_align_right = ":/icons/icons/cil-align-right.png"
    cil_arrow_bottom_2 = ":/icons/icons/cil-arrow-bottom-2.png"
    cil_arrow_bottom = ":/icons/icons/cil-arrow-bottom.png"
    cil_arrow_circle_bottom = ":/icons/icons/cil-arrow-circle-bottom.png"
    cil_arrow_circle_left = ":/icons/icons/cil-arrow-circle-left.png"
    cil_arrow_circle_right = ":/icons/icons/cil-arrow-circle-right.png"
    cil_arrow_circle_top = ":/icons/icons/cil-arrow-circle-top.png"
    cil_arrow_left = ":/icons/icons/cil-arrow-left.png"
    cil_arrow_right = ":/icons/icons/cil-arrow-right.png"
    cil_arrow_top = ":/icons/icons/cil-arrow-top.png"
    cil_at = ":/icons/icons/cil-at.png"
    cil_av_timer = ":/icons/icons/cil-av-timer.png"
    cil_ban = ":/icons/icons/cil-ban.png"
    cil_battery_0 = ":/icons/icons/cil-battery-0.png"
    cil_battery_3 = ":/icons/icons/cil-battery-3.png"
    cil_battery_5 = ":/icons/icons/cil-battery-5.png"
    cil_battery_alert = ":/icons/icons/cil-battery-alert.png"
    cil_battery_slash = ":/icons/icons/cil-battery-slash.png"
    cil_bell = ":/icons/icons/cil-bell.png"
    cil_bluetooth = ":/icons/icons/cil-bluetooth.png"
    cil_briefcase = ":/icons/icons/cil-briefcase.png"
    cil_browser = ":/icons/icons/cil-browser.png"
    cil_calendar_check = ":/icons/icons/cil-calendar-check.png"
    cil_camera_roll = ":/icons/icons/cil-camera-roll.png"
    cil_camera = ":/icons/icons/cil-camera.png"
    cil_caret_bottom = ":/icons/icons/cil-caret-bottom.png"
    cil_caret_left = ":/icons/icons/cil-caret-left.png"
    cil_caret_right = ":/icons/icons/cil-caret-right.png"
    cil_caret_top = ":/icons/icons/cil-caret-top.png"
    cil_cart = ":/icons/icons/cil-cart.png"
    cil_cast = ":/icons/icons/cil-cast.png"
    cil_chart_line = ":/icons/icons/cil-chart-line.png"
    cil_chart_pie = ":/icons/icons/cil-chart-pie.png"
    cil_chart = ":/icons/icons/cil-chart.png"
    cil_chat_bubble = ":/icons/icons/cil-chat-bubble.png"
    cil_check_alt = ":/icons/icons/cil-check-alt.png"
    cil_check_circle = ":/icons/icons/cil-check-circle.png"
    cil_check = ":/icons/icons/cil-check.png"
    cil_chevron_bottom = ":/icons/icons/cil-chevron-bottom.png"
    cil_chevron_circle_down_alt = ":/icons/icons/cil-chevron-circle-down-alt.png"
    cil_chevron_circle_left_alt = ":/icons/icons/cil-chevron-circle-left-alt.png"
    cil_chevron_circle_right_alt = ":/icons/icons/cil-chevron-circle-right-alt.png"
    cil_chevron_circle_up_alt = ":/icons/icons/cil-chevron-circle-up-alt.png"
    cil_chevron_double_down = ":/icons/icons/cil-chevron-double-down.png"
    cil_chevron_double_left = ":/icons/icons/cil-chevron-double-left.png"
    cil_chevron_double_right = ":/icons/icons/cil-chevron-double-right.png"
    cil_chevron_double_up_alt = ":/icons/icons/cil-chevron-double-up-alt.png"
    cil_chevron_double_up = ":/icons/icons/cil-chevron-double-up.png"
    cil_chevron_left = ":/icons/icons/cil-chevron-left.png"
    cil_chevron_right = ":/icons/icons/cil-chevron-right.png"
    cil_chevron_top = ":/icons/icons/cil-chevron-top.png"
    cil_circle = ":/icons/icons/cil-circle.png"
    cil_clipboard = ":/icons/icons/cil-clipboard.png"
    cil_clock = ":/icons/icons/cil-clock.png"
    cil_clone = ":/icons/icons/cil-clone.png"
    cil_closed_captioning = ":/icons/icons/cil-closed-captioning.png"
    cil_cloud_download = ":/icons/icons/cil-cloud-download.png"
    cil_cloud_upload = ":/icons/icons/cil-cloud-upload.png"
    cil_cloudy = ":/icons/icons/cil-cloudy.png"
    cil_code = ":/icons/icons/cil-code.png"
    cil_coffee = ":/icons/icons/cil-coffee.png"
    cil_comment_bubble = ":/icons/icons/cil-comment-bubble.png"
    cil_comment_square = ":/icons/icons/cil-comment-square.png"
    cil_credit_card = ":/icons/icons/cil-credit-card.png"
    cil_cursor_move = ":/icons/icons/cil-cursor-move.png"
    cil_cursor = ":/icons/icons/cil-cursor.png"
    cil_cut = ":/icons/icons/cil-cut.png"
    cil_data_transfer_down = ":/icons/icons/cil-data-transfer-down.png"
    cil_data_transfer_up = ":/icons/icons/cil-data-transfer-up.png"
    cil_deaf = ":/icons/icons/cil-deaf.png"
    cil_description = ":/icons/icons/cil-description.png"
    cil_devices = ":/icons/icons/cil-devices.png"
    cil_dialpad = ":/icons/icons/cil-dialpad.png"
    cil_dog = ":/icons/icons/cil-dog.png"
    cil_door = ":/icons/icons/cil-door.png"
    cil_double_quote_sans_left = ":/icons/icons/cil-double-quote-sans-left.png"
    cil_double_quote_sans_right = ":/icons/icons/cil-double-quote-sans-right.png"
    cil_drop = ":/icons/icons/cil-drop.png"
    cil_envelope_closed = ":/icons/icons/cil-envelope-closed.png"
    cil_envelope_letter = ":/icons/icons/cil-envelope-letter.png"
    cil_envelope_open = ":/icons/icons/cil-envelope-open.png"
    cil_equalizer = ":/icons/icons/cil-equalizer.png"
    cil_ethernet = ":/icons/icons/cil-ethernet.png"
    cil_exit_to_app = ":/icons/icons/cil-exit-to-app.png"
    cil_expand_down = ":/icons/icons/cil-expand-down.png"
    cil_expand_left = ":/icons/icons/cil-expand-left.png"
    cil_expand_right = ":/icons/icons/cil-expand-right.png"
    cil_expand_up = ":/icons/icons/cil-expand-up.png"
    cil_exposure = ":/icons/icons/cil-exposure.png"
    cil_external_link = ":/icons/icons/cil-external-link.png"
    cil_face_dead = ":/icons/icons/cil-face-dead.png"
    cil_featured_playlist = ":/icons/icons/cil-featured-playlist.png"
    cil_file = ":/icons/icons/cil-file.png"
    cil_find_in_page = ":/icons/icons/cil-find-in-page.png"
    cil_fingerprint = ":/icons/icons/cil-fingerprint.png"
    cil_fire = ":/icons/icons/cil-fire.png"
    cil_flip_to_back = ":/icons/icons/cil-flip-to-back.png"
    cil_folder_open = ":/icons/icons/cil-folder-open.png"
    cil_folder = ":/icons/icons/cil-folder.png"
    cil_frown = ":/icons/icons/cil-frown.png"
    cil_gamepad = ":/icons/icons/cil-gamepad.png"
    cil_hand_point_down = ":/icons/icons/cil-hand-point-down.png"
    cil_hand_point_left = ":/icons/icons/cil-hand-point-left.png"
    cil_hand_point_right = ":/icons/icons/cil-hand-point-right.png"
    cil_hand_point_up = ":/icons/icons/cil-hand-point-up.png"
    cil_hd = ":/icons/icons/cil-hd.png"
    cil_hdr = ":/icons/icons/cil-hdr.png"
    cil_headphones = ":/icons/icons/cil-headphones.png"
    cil_heart = ":/icons/icons/cil-heart.png"
    cil_highligt = ":/icons/icons/cil-highligt.png"
    cil_history = ":/icons/icons/cil-history.png"
    cil_home = ":/icons/icons/cil-home.png"
    cil_house = ":/icons/icons/cil-house.png"
    cil_image_plus = ":/icons/icons/cil-image-plus.png"
    cil_image1 = ":/icons/icons/cil-image1.png"
    cil_infinity = ":/icons/icons/cil-infinity.png"
    cil_input_power = ":/icons/icons/cil-input-power.png"
    cil_input = ":/icons/icons/cil-input.png"
    cil_justify_center = ":/icons/icons/cil-justify-center.png"
    cil_justify_left = ":/icons/icons/cil-justify-left.png"
    cil_justify_right = ":/icons/icons/cil-justify-right.png"
    cil_keyboard = ":/icons/icons/cil-keyboard.png"
    cil_laptop = ":/icons/icons/cil-laptop.png"
    cil_layers = ":/icons/icons/cil-layers.png"
    cil_level_down = ":/icons/icons/cil-level-down.png"
    cil_level_up = ":/icons/icons/cil-level-up.png"
    cil_library_add = ":/icons/icons/cil-library-add.png"
    cil_library = ":/icons/icons/cil-library.png"
    cil_lightbulb = ":/icons/icons/cil-lightbulb.png"
    cil_link_alt = ":/icons/icons/cil-link-alt.png"
    cil_link_broken = ":/icons/icons/cil-link-broken.png"
    cil_link = ":/icons/icons/cil-link.png"
    cil_location_pin = ":/icons/icons/cil-location-pin.png"
    cil_lock_locked = ":/icons/icons/cil-lock-locked.png"
    cil_lock_unlocked = ":/icons/icons/cil-lock-unlocked.png"
    cil_loop_1 = ":/icons/icons/cil-loop-1.png"
    cil_loop_circular = ":/icons/icons/cil-loop-circular.png"
    cil_loop = ":/icons/icons/cil-loop.png"
    cil_low_vision = ":/icons/icons/cil-low-vision.png"
    cil_magnifying_glass = ":/icons/icons/cil-magnifying-glass.png"
    cil_map = ":/icons/icons/cil-map.png"
    cil_media_eject = ":/icons/icons/cil-media-eject.png"
    cil_media_pause = ":/icons/icons/cil-media-pause.png"
    cil_media_play = ":/icons/icons/cil-media-play.png"
    cil_media_skip_backward = ":/icons/icons/cil-media-skip-backward.png"
    cil_media_skip_forward = ":/icons/icons/cil-media-skip-forward.png"
    cil_media_step_backward = ":/icons/icons/cil-media-step-backward.png"
    cil_media_step_forward = ":/icons/icons/cil-media-step-forward.png"
    cil_media_stop = ":/icons/icons/cil-media-stop.png"
    cil_medical_cross = ":/icons/icons/cil-medical-cross.png"
    cil_meh = ":/icons/icons/cil-meh.png"
    cil_menu = ":/icons/icons/cil-menu.png"
    cil_microphone = ":/icons/icons/cil-microphone.png"
    cil_minus = ":/icons/icons/cil-minus.png"
    cil_mobile_landscape = ":/icons/icons/cil-mobile-landscape.png"
    cil_mobile = ":/icons/icons/cil-mobile.png"
    cil_mood_bad = ":/icons/icons/cil-mood-bad.png"
    cil_mood_good = ":/icons/icons/cil-mood-good.png"
    cil_mood_very_bad = ":/icons/icons/cil-mood-very-bad.png"
    cil_mood_very_good = ":/icons/icons/cil-mood-very-good.png"
    cil_moon = ":/icons/icons/cil-moon.png"
    cil_mouse = ":/icons/icons/cil-mouse.png"
    cil_move = ":/icons/icons/cil-move.png"
    cil_movie = ":/icons/icons/cil-movie.png"
    cil_mug_tea = ":/icons/icons/cil-mug-tea.png"
    cil_mug = ":/icons/icons/cil-mug.png"
    cil_notes = ":/icons/icons/cil-notes.png"
    cil_options_horizontal = ":/icons/icons/cil-options-horizontal.png"
    cil_options = ":/icons/icons/cil-options.png"
    cil_paint_bucket = ":/icons/icons/cil-paint-bucket.png"
    cil_paper_plane = ":/icons/icons/cil-paper-plane.png"
    cil_paperclip = ":/icons/icons/cil-paperclip.png"
    cil_paragraph = ":/icons/icons/cil-paragraph.png"
    cil_pen_alt = ":/icons/icons/cil-pen-alt.png"
    cil_pencil = ":/icons/icons/cil-pencil.png"
    cil_people = ":/icons/icons/cil-people.png"
    cil_phone = ":/icons/icons/cil-phone.png"
    cil_pin = ":/icons/icons/cil-pin.png"
    cil_plus = ":/icons/icons/cil-plus.png"
    cil_power_standby = ":/icons/icons/cil-power-standby.png"
    cil_print = ":/icons/icons/cil-print.png"
    cil_rectangle = ":/icons/icons/cil-rectangle.png"
    cil_reload = ":/icons/icons/cil-reload.png"
    cil_remove = ":/icons/icons/cil-remove.png"
    cil_rss = ":/icons/icons/cil-rss.png"
    cil_satelite = ":/icons/icons/cil-satelite.png"
    cil_save = ":/icons/icons/cil-save.png"
    cil_screen_desktop = ":/icons/icons/cil-screen-desktop.png"
    cil_screen_smartphone = ":/icons/icons/cil-screen-smartphone.png"
    cil_settings = ":/icons/icons/cil-settings.png"
    cil_share_boxed = ":/icons/icons/cil-share-boxed.png"
    cil_share = ":/icons/icons/cil-share.png"
    cil_signal_cellular_0 = ":/icons/icons/cil-signal-cellular-0.png"
    cil_signal_cellular_3 = ":/icons/icons/cil-signal-cellular-3.png"
    cil_size_grip = ":/icons/icons/cil-size-grip.png"
    cil_smile = ":/icons/icons/cil-smile.png"
    cil_speaker = ":/icons/icons/cil-speaker.png"
    cil_speech = ":/icons/icons/cil-speech.png"
    cil_speedometer = ":/icons/icons/cil-speedometer.png"
    cil_star = ":/icons/icons/cil-star.png"
    cil_tags = ":/icons/icons/cil-tags.png"
    cil_task = ":/icons/icons/cil-task.png"
    cil_terminal = ":/icons/icons/cil-terminal.png"
    cil_text_size = ":/icons/icons/cil-text-size.png"
    cil_text_square = ":/icons/icons/cil-text-square.png"
    cil_text = ":/icons/icons/cil-text.png"
    cil_thumb_down = ":/icons/icons/cil-thumb-down.png"
    cil_thumb_up = ":/icons/icons/cil-thumb-up.png"
    cil_transfer = ":/icons/icons/cil-transfer.png"
    cil_trash = ":/icons/icons/cil-trash.png"
    cil_triangle = ":/icons/icons/cil-triangle.png"
    cil_truck = ":/icons/icons/cil-truck.png"
    cil_user_female = ":/icons/icons/cil-user-female.png"
    cil_user_follow = ":/icons/icons/cil-user-follow.png"
    cil_user_unfollow = ":/icons/icons/cil-user-unfollow.png"
    cil_user = ":/icons/icons/cil-user.png"
    cil_vertical_align_bottom = ":/icons/icons/cil-vertical-align-bottom.png"
    cil_view_column = ":/icons/icons/cil-view-column.png"
    cil_view_module = ":/icons/icons/cil-view-module.png"
    cil_view_quilt = ":/icons/icons/cil-view-quilt.png"
    cil_view_stream = ":/icons/icons/cil-view-stream.png"
    cil_voice_over_record = ":/icons/icons/cil-voice-over-record.png"
    cil_volume_high = ":/icons/icons/cil-volume-high.png"
    cil_volume_low = ":/icons/icons/cil-volume-low.png"
    cil_volume_off = ":/icons/icons/cil-volume-off.png"
    cil_wallet = ":/icons/icons/cil-wallet.png"
    cil_watch = ":/icons/icons/cil-watch.png"
    cil_wifi_signal_0 = ":/icons/icons/cil-wifi-signal-0.png"
    cil_wifi_signal_1 = ":/icons/icons/cil-wifi-signal-1.png"
    cil_wifi_signal_2 = ":/icons/icons/cil-wifi-signal-2.png"
    cil_wifi_signal_4 = ":/icons/icons/cil-wifi-signal-4.png"
    cil_wifi_signal_off = ":/icons/icons/cil-wifi-signal-off.png"
    cil_window_maximize = ":/icons/icons/cil-window-maximize.png"
    cil_window_minimize = ":/icons/icons/cil-window-minimize.png"
    cil_window_restore = ":/icons/icons/cil-window-restore.png"
    cil_wrap_text = ":/icons/icons/cil-wrap-text.png"
    cil_x_circle = ":/icons/icons/cil-x-circle.png"
    cil_x = ":/icons/icons/cil-x.png"
    cil_zoom_in = ":/icons/icons/cil-zoom-in.png"
    cil_zoom_out = ":/icons/icons/cil-zoom-out.png"
    icon_close = ":/icons/icons/icon_close.png"
    icon_maximize = ":/icons/icons/icon_maximize.png"
    icon_menu = ":/icons/icons/icon_menu.png"
    icon_minimize = ":/icons/icons/icon_minimize.png"
    icon_restore = ":/icons/icons/icon_restore.png"
    icon_settings = ":/icons/icons/icon_settings.png"
    material_circled_C = ":/icons/icons/material-circled-C.png"
    material_circled_K = ":/icons/icons/material-circled-K.png"
    material_copy_24 = ":/icons/icons/material-copy-24.png"
    material_electricity = ":/icons/icons/material-electricity.png"
    material_play_blue = ":/icons/icons/material-play-blue.png"
    material_stop_red = ":/icons/icons/material-stop-red.png"
