# -*- coding: utf-8 -*-
"""
Configuration des traductions pour EzQt_App
"""

# Langues supportées
SUPPORTED_LANGUAGES = {
    "en": {
        "name": "English",
        "native_name": "English",
        "file": "ezqt_app_en.ts"
    },
    "fr": {
        "name": "Français", 
        "native_name": "Français",
        "file": "ezqt_app_fr.ts"
    },
    "es": {
        "name": "Español",
        "native_name": "Español", 
        "file": "ezqt_app_es.ts"
    },
    "de": {
        "name": "Deutsch",
        "native_name": "Deutsch",
        "file": "ezqt_app_de.ts"
    }
}

# Langue par défaut
DEFAULT_LANGUAGE = "en"

# Dossier des traductions
TRANSLATIONS_DIR = "resources/translations"
